bayespy.inference.vmp.nodes.gaussian.GaussianMoments.__init__
=============================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianMoments.__init__